summaryrefslogtreecommitdiffstats
path: root/kmplot/kmplot/keditpolar.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmplot/kmplot/keditpolar.h')
-rw-r--r--kmplot/kmplot/keditpolar.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/kmplot/kmplot/keditpolar.h b/kmplot/kmplot/keditpolar.h
index 131f2475..8b199110 100644
--- a/kmplot/kmplot/keditpolar.h
+++ b/kmplot/kmplot/keditpolar.h
@@ -36,11 +36,12 @@ class XParser;
class KEditPolar : public QEditPolar
{
Q_OBJECT
+ TQ_OBJECT
public:
/// @param parser points to the parser instance.
/// @param parent points to the parent widget.
/// @param name of this instance.
- KEditPolar( XParser* parser, TQWidget* parent = NULL, const char* name = NULL );
+ KEditPolar( XParser* parser, TQWidget* tqparent = NULL, const char* name = NULL );
/// Nothing special to do.
virtual ~KEditPolar() {}
@@ -66,7 +67,8 @@ class KEditPolar : public QEditPolar
void slotHelp();
void customMinRange_toggled(bool);
void customMaxRange_toggled(bool);
-
+
+ protected:
Ufkt *m_updatedfunction;
};
@@ -36,11 +36,12 @@ class XParser;
public:
/// @param parser points to the parser instance.
- /// @param parent points to the parent widget.
+ /// @param tqparent points to the tqparent widget.
/// @param name of this instance.